Crate slow5lib_sys
source · [−]Structs
@struct slow5_aux_meta SLOW5 auxiliary field metadata (information available in the SLOW5 header)
@struct slow5_file SLOW5 file structure
@struct slow5_file SLOW5 file meta data
@struct slow5_fmt_meta SLOW5 file meta data
@struct slow5_hdr SLOW5 header
@struct slow5_hdr_data SLOW5 header data (constant attributes in FAST5 files)
@struct slow5_rec SLOW5 record data struct (represents a single SLOW5 record)
@struct slow5_rec_aux_data SLOW5 auxiliary field data (represents a single SLOW5 auxiliary field of a particular read record)
@struct slow5_version @brief SLOW5 file version
Constants
< the format is ASCII SLOW5
< the format is binary SLOW5 (that is, BLOW5)
< the format is unknown, usually the case before parsing the file extension
Statics
Functions
Add a read entry to the SLOW5 file while updating the SLOW5 index (not thread safe).
Get an auxiliary field in a SLOW5 record as an 8-bit signed integer.
Get an auxiliary field in a SLOW5 record as an 8-bit signed integer array.
Close a slow5 file and free its memory.
Print the binary end of file to a file pointer.
get the enum labels for a specific auxiliary field and set the number of labels in *n return NULL on error and slow5_errno set to SLOW5_ERR_ARG if header, field NULL, n can be NULL SLOW5_ERR_NOAUX if auxiliary header is NULL SLOW5_ERR_TYPE if the enum labels or num_labels array is NULL, or the field type is not an enum type SLOW5_ERR_NOFLD if the auxiliary field was not found SLOW5_ERR_MEM memory allocation error
Get the read entry under the current file pointer of a slow5 file.
Add a new header data attribute.
Add a new header read group.
Print the header in the specified format to a file pointer.
Get a header data attribute for a particular read_group.
Set a header data attribute for a particular read_group.
Get the header in the specified format.
Create the index file for slow5 file. Overwrites if already exists.
Loads the index file for slow5 file. Creates the index if not found.
Create the index file for slow5 file. Overrides if already exists.
Unloads an index associted to a slow5_file_t using slow5_idx_load and free the memory.
Ultra-Low-level API ******************************************************************************
Open a slow5 file with a specific mode given it’s pathname.
Open a slow5 file of a specific format with a mode given it’s pathname.
Free a slow5 record.
Print a read entry in the specified format to a file pointer.
Get the read entry in the specified format.
Remove a read entry at a read_id in a slow5 file while updating the SLOW5 index (not thread safe).
Type Definitions
@struct slow5_aux_meta SLOW5 auxiliary field metadata (information available in the SLOW5 header)
SLOW5 record
@struct slow5_file SLOW5 file meta data
@struct slow5_file SLOW5 file structure
@enum slow5_fmt File formats we are dealing with
@struct slow5_hdr_data SLOW5 header data (constant attributes in FAST5 files)
@struct slow5_hdr SLOW5 header
@struct slow5_rec SLOW5 record data struct (represents a single SLOW5 record)