Function slow5lib_sys::slow5_eof_fwrite
source · [−]Expand description
Print the binary end of file to a file pointer.
On success, the number of bytes written is returned. On error, -1 is returned.
@param fp output file pointer @return number of bytes written, -1 on error