pub unsafe extern "C" fn slow5_open(
    pathname: *const c_char,
    mode: *const c_char
) -> *mut slow5_file_t
Open a slow5 file with a specific mode given it’s pathname.

Attempt to guess the file’s slow5 format from the pathname’s extension. Return NULL on error.

If successful, return a slow5 file structure with the header parsed. slow5_close() should be called when finished with the structure.

The user at the moment is expected to give “r” TODO : Make “r” into “rb” if BLOW5 - this is not an issue for POSIX systems as mode b is not used [https://man7.org/linux/man-pages/man3/fopen.3.html]

@param pathname relative or absolute path to slow5 file @param mode only “r” for the moment for reading @return slow5 file structure