#[repr(C)]
pub struct slow5_hdr { pub version: slow5_version, pub num_read_groups: u32, pub data: slow5_hdr_data_t, pub aux_meta: *mut slow5_aux_meta_t, }
@struct slow5_hdr SLOW5 header

Fields

version: slow5_version

< SLOW5 file version

num_read_groups: u32

< Number of read groups

data: slow5_hdr_data_t

< Header data (constant fields in FAST5 files). Not to be directly accessed, use provided functions instead.

aux_meta: *mut slow5_aux_meta_t

< Auxiliary field metadata. Not to be directly accessed, use provided functions instead.