Function slow5lib_sys::slow5_hdr_fwrite
source · [−]pub unsafe extern "C" fn slow5_hdr_fwrite(
fp: *mut FILE,
header: *mut slow5_hdr_t,
format: slow5_fmt,
comp: slow5_press_method_t
) -> c_intExpand description
Print the header in the specified format to a file pointer.
On success, the number of bytes written is returned. On error, -1 is returned.
@param fp output file pointer @param header slow5 header @param format slow5 format to write the entry in @param comp compression method @return number of bytes written, -1 on error