#[repr(C)]
pub struct slow5_hdr_data { pub num_attrs: u32, pub attrs: *mut kh_slow5_s_t, pub maps: slow5_hdr_data__bindgen_ty_1, }
@struct slow5_hdr_data SLOW5 header data (constant attributes in FAST5 files)

Fields

num_attrs: u32

< Number of data attributes

attrs: *mut kh_slow5_s_t

< Set of the data attribute keys for internal access(incase of multiple read groups, the union of keys from all read groups)

maps: slow5_hdr_data__bindgen_ty_1

< Dynamic vector of hash maps (attribute key string -> attribute value string). Length of the vector is requal to num_read_groups. Index in the vector corresponds to the read group number. The keys that are not relevant to a particular read group are not stored in this hash map.